@@ -8,7 +8,7 @@ from typing import Annotated, Optional
 
 import typer
 
-from memium.core import main
+from memium.core import core
 
 log = logging.getLogger(__name__)
 
@@ -25,7 +25,7 @@ def cli(
             file_okay=False,
             exists=True,
             readable=True,
-            writable=True,
+            writable=False,
         ),
     ],
     watch_seconds: Annotated[
@@ -65,7 +65,7 @@ def cli(
         ],
         level=logging.INFO,
         format="%(asctime)s [%(levelname)s] %(name)s: %(message)s",
-        datefmt="%Y/&m/%d %H:%M:%S",
+        datefmt="%Y/%m/%d %H:%M:%S",
     )
 
     if skip_sync:
@@ -73,7 +73,7 @@ def cli(
         return
 
     main_fn = partial(
-        main,
+        core,
         base_deck=deck_name,
         input_dir=input_dir,
         max_deletions_per_run=max_deletions_per_run,
