@@ -3,18 +3,16 @@ from pathlib import Path
 
 import pytest
 
-from memium.__main__ import main
+from memium.core import core
 
 from .destination.ankiconnect.ankiconnect_gateway import anki_connect_is_live
 
 
 @pytest.mark.skipif(
-    not anki_connect_is_live(),
-    reason="Tests require a running AnkiConnect server",
+    not anki_connect_is_live() or not Path("/output").exists(),
+    reason="Tests require a running AnkiConnect server and an output directory. Use the Docker container to run the tests.",
 )
-def test_main(
-    caplog: pytest.LogCaptureFixture, base_deck: str = "Main Integration Test"
-):
+def test_main(caplog: pytest.LogCaptureFixture, base_deck: str = "Main Integration Test"):
     caplog.set_level(logging.INFO)
 
     # Clear and delete output path
@@ -29,21 +27,16 @@ def test_main(
 
     with (test_input_path / "test.md").open("w") as f:
         f.write(
-            """Q. Question
+            """Q. What are [[Trees]]?
 A. å
 """
         )
 
-    main(
-        base_deck=base_deck,
-        input_dir=test_input_path,
-        max_deletions_per_run=2,
-        dry_run=False,
-    )
+    core(base_deck=base_deck, input_dir=test_input_path, max_deletions_per_run=2, dry_run=False)
     assert "Pushing 1 cards to Anki" in caplog.text
 
     # Test idempotency
-    main(
+    core(
         base_deck=base_deck,
         input_dir=test_input_path,
         max_deletions_per_run=0,  # 0 deletions allowed to test idempotency
